@@ -5,7 +5,6 @@
 __author__ = 'Zitong Lu'
 
 import numpy as np
-import math
 from neurora.rdm_corr import rdm_correlation_spearman
 from neurora.rdm_corr import rdm_correlation_pearson
 from neurora.rdm_corr import rdm_correlation_kendall
@@ -17,7 +16,7 @@ np.seterr(divide='ignore', invalid='ignore')
 
 ' a function for calculating the Similarity/Correlation Cosfficient between RDMs based on EEG/MEG/fNIRS/ECoG/sEEG/electrophysiological RDMs and a demo RDM'
 
-def rdms_corr(demo_rdm, eeg_rdms, method="spearman", rescale=False):
+def rdms_corr(demo_rdm, eeg_rdms, method="spearman", rescale=False, permutation=False, iter=5000):
 
     """
     Calculate the Similarities between EEG/MEG/fNIRS/ECoG/sEEG/electrophysiological RDMs and a demo RDM
@@ -38,6 +37,10 @@ def rdms_corr(demo_rdm, eeg_rdms, method="spearman", rescale=False):
     rescale : bool True or False.
         Rescale the values in RDM or not.
         Here, the maximum-minimum method is used to rescale the values except for the values on the diagonal.
+    permutation : bool True or False. Default is False.
+        Use permutation test or not.
+    iter : int. Default is 5000.
+        The times for iteration.
 
     Returns
     -------
@@ -63,15 +66,15 @@ def rdms_corr(demo_rdm, eeg_rdms, method="spearman", rescale=False):
                 for k in range(n3):
 
                     if method == "spearman":
-                        corrs[i, j] = rdm_correlation_spearman(demo_rdm, eeg_rdms[i, j], rescale=rescale)
+                        corrs[i, j] = rdm_correlation_spearman(demo_rdm, eeg_rdms[i, j], rescale=rescale, permutation=permutation, iter=iter)
                     elif method == "pearson":
-                        corrs[i, j] = rdm_correlation_pearson(demo_rdm, eeg_rdms[i, j], rescale=rescale)
+                        corrs[i, j] = rdm_correlation_pearson(demo_rdm, eeg_rdms[i, j], rescale=rescale, permutation=permutation, iter=iter)
                     elif method == "kendall":
-                        corrs[i, j] = rdm_correlation_kendall(demo_rdm, eeg_rdms[i, j], rescale=rescale)
+                        corrs[i, j] = rdm_correlation_kendall(demo_rdm, eeg_rdms[i, j], rescale=rescale, permutation=permutation, iter=iter)
                     elif method == "similarity":
-                        corrs[i, j, 0] = rdm_similarity(demo_rdm, eeg_rdms[i, j], rescale=rescale)
+                        corrs[i, j, 0] = rdm_similarity(demo_rdm, eeg_rdms[i, j], rescale=rescale, permutation=permutation, iter=iter)
                     elif method == "distance":
-                        corrs[i, j, 0] = rdm_distance(demo_rdm, eeg_rdms[i, j], rescale=rescale)
+                        corrs[i, j, 0] = rdm_distance(demo_rdm, eeg_rdms[i, j], rescale=rescale, permutation=permutation, iter=iter)
 
         return corrs
 
@@ -87,11 +90,11 @@ def rdms_corr(demo_rdm, eeg_rdms, method="spearman", rescale=False):
             for j in range(n2):
 
                 if method == "spearman":
-                    corrs[i, j] = rdm_correlation_spearman(demo_rdm, eeg_rdms[i, j], rescale=rescale)
+                    corrs[i, j] = rdm_correlation_spearman(demo_rdm, eeg_rdms[i, j], rescale=rescale, permutation=permutation, iter=iter)
                 elif method == "pearson":
-                    corrs[i, j] = rdm_correlation_pearson(demo_rdm, eeg_rdms[i, j], rescale=rescale)
+                    corrs[i, j] = rdm_correlation_pearson(demo_rdm, eeg_rdms[i, j], rescale=rescale, permutation=permutation, iter=iter)
                 elif method == "kendall":
-                    corrs[i, j] = rdm_correlation_kendall(demo_rdm, eeg_rdms[i, j], rescale=rescale)
+                    corrs[i, j] = rdm_correlation_kendall(demo_rdm, eeg_rdms[i, j], rescale=rescale, permutation=permutation, iter=iter)
                 elif method == "similarity":
                     corrs[i, j, 0] = rdm_similarity(demo_rdm, eeg_rdms[i, j], rescale=rescale)
                 elif method == "distance":
@@ -109,11 +112,11 @@ def rdms_corr(demo_rdm, eeg_rdms, method="spearman", rescale=False):
         # calculate the corrs
         for i in range(n1):
             if method == "spearman":
-                corrs[i] = rdm_correlation_spearman(demo_rdm, eeg_rdms[i], rescale=rescale)
+                corrs[i] = rdm_correlation_spearman(demo_rdm, eeg_rdms[i], rescale=rescale, permutation=permutation, iter=iter)
             elif method == "pearson":
-                corrs[i] = rdm_correlation_pearson(demo_rdm, eeg_rdms[i], rescale=rescale)
+                corrs[i] = rdm_correlation_pearson(demo_rdm, eeg_rdms[i], rescale=rescale, permutation=permutation, iter=iter)
             elif method == "kendall":
-                corrs[i] = rdm_correlation_kendall(demo_rdm, eeg_rdms[i], rescale=rescale)
+                corrs[i] = rdm_correlation_kendall(demo_rdm, eeg_rdms[i], rescale=rescale, permutation=permutation, iter=iter)
             elif method == "similarity":
                 corrs[i, 0] = rdm_similarity(demo_rdm, eeg_rdms[i], rescale=rescale)
             elif method == "distance":
@@ -126,11 +129,11 @@ def rdms_corr(demo_rdm, eeg_rdms, method="spearman", rescale=False):
 
     # calculate the corrs
     if method == "spearman":
-        corr = rdm_correlation_spearman(demo_rdm, eeg_rdms, rescale=rescale)
+        corr = rdm_correlation_spearman(demo_rdm, eeg_rdms, rescale=rescale, permutation=permutation, iter=iter)
     elif method == "pearson":
-        corr = rdm_correlation_pearson(demo_rdm, eeg_rdms, rescale=rescale)
+        corr = rdm_correlation_pearson(demo_rdm, eeg_rdms, rescale=rescale, permutation=permutation, iter=iter)
     elif method == "kendall":
-        corr = rdm_correlation_kendall(demo_rdm, eeg_rdms, rescale=rescale)
+        corr = rdm_correlation_kendall(demo_rdm, eeg_rdms, rescale=rescale, permutation=permutation, iter=iter)
     elif method == "similarity":
         corr[0] = rdm_similarity(demo_rdm, eeg_rdms, rescale=rescale)
     elif method == "distance":
@@ -141,7 +144,7 @@ def rdms_corr(demo_rdm, eeg_rdms, method="spearman", rescale=False):
 
 ' a function for calculating the Similarity/Correlation Cosfficient between fMRI RDMs and a demo RDM'
 
-def fmrirdms_corr(demo_rdm, fmri_rdms, method="spearman", rescale=False):
+def fmrirdms_corr(demo_rdm, fmri_rdms, method="spearman", rescale=False, permutation=False, iter=5000):
 
 
     """
@@ -163,6 +166,10 @@ def fmrirdms_corr(demo_rdm, fmri_rdms, method="spearman", rescale=False):
     rescale : bool True or False.
         Rescale the values in RDM or not.
         Here, the maximum-minimum method is used to rescale the values except for the values on the diagonal.
+    permutation : bool True or False. Default is False.
+        Use permutation test or not.
+    iter : int. Default is 5000.
+        The times for iteration.
 
     Returns
     -------
@@ -185,11 +192,11 @@ def fmrirdms_corr(demo_rdm, fmri_rdms, method="spearman", rescale=False):
             for k in range(n_z):
 
                 if method == "spearman":
-                    corrs[i, j, k] = rdm_correlation_spearman(demo_rdm, fmri_rdms[i, j, k], rescale=rescale)
+                    corrs[i, j, k] = rdm_correlation_spearman(demo_rdm, fmri_rdms[i, j, k], rescale=rescale, permutation=permutation, iter=iter)
                 elif method == "pearson":
-                    corrs[i, j, k] = rdm_correlation_pearson(demo_rdm, fmri_rdms[i, j, k], rescale=rescale)
+                    corrs[i, j, k] = rdm_correlation_pearson(demo_rdm, fmri_rdms[i, j, k], rescale=rescale, permutation=permutation, iter=iter)
                 elif method == "kendall":
-                    corrs[i, j, k] = rdm_correlation_kendall(demo_rdm, fmri_rdms[i, j, k], rescale=rescale)
+                    corrs[i, j, k] = rdm_correlation_kendall(demo_rdm, fmri_rdms[i, j, k], rescale=rescale, permutation=permutation, iter=iter)
                 elif method == "similarity":
                     corrs[i, j, k, 0] = rdm_similarity(demo_rdm, fmri_rdms[i, j, k], rescale=rescale)
                 elif method == "distance":
@@ -197,4 +204,4 @@ def fmrirdms_corr(demo_rdm, fmri_rdms, method="spearman", rescale=False):
 
                 print(corrs[i, j, k])
 
-    return np.abs(corrs)
\ No newline at end of file
+    return corrs
\ No newline at end of file
