@@ -288,7 +288,7 @@ def plot_corrs_hotmap(corrs, chllabels=None, time_unit=[0, 0.1], lim=[0, 1], smo
         The time information of corrs for plotting
         start_t represents the start time and t_step represents the time between two adjacent time-points. Default
         time_unit=[0, 0.1], which means the start time of corrs is 0 sec and the time step is 0.1 sec.
-    lim : array or list [min, max].
+    lim : array or list [min, max]. Default is [0, 1].
         The corrs view lims.
     smooth : bool True or False
         Smooth the results or not.
@@ -426,7 +426,7 @@ def plot_nps_hotmap(similarities, chllabels=None, time_unit=[0, 0.1], lim=[0, 1]
         The time information of corrs for plotting
         start_t represents the start time and t_step represents the time between two adjacent time-points. Default
         time_unit=[0, 0.1], which means the start time of corrs is 0 sec and the time step is 0.1 sec.
-    lim : array or list [min, max].
+    lim : array or list [min, max]. Default is [0, 1].
         The corrs view lims.
     abs : boolean True or False.
         Change the similarities into absolute values or not.
@@ -541,9 +541,155 @@ def plot_nps_hotmap(similarities, chllabels=None, time_unit=[0, 0.1], lim=[0, 1]
     plt.show()
 
 
+' a function for plotting the hotmap of statistical results for channels/regions by time sequence '
+
+def plot_stats_hotmap(stats, chllabels=None, time_unit=[0, 0.1], lim=[-7, 7], smooth=False, figsize=None, cmap=None, outline=False):
+
+    """
+    plot the hotmap of statistical results for channels/regions by time sequence
+
+    stats : array
+        The statistical results.
+        The shape of stats must be [n_chls, ts, 2]. n_chls represents the number of channels or regions.
+        ts represents the number of time-points. 2 represents a t-value and a p-value.
+    chllabel : string-array or string-list or None. Default is None.
+        The label for channels/regions.
+        If label=None, the labels will be '1st', '2nd', '3th', '4th', ... automatically.
+    time_unit : array or list [start_t, t_step]. Default is [0, 0.1]
+        The time information of corrs for plotting
+        start_t represents the start time and t_step represents the time between two adjacent time-points. Default
+        time_unit=[0, 0.1], which means the start time of corrs is 0 sec and the time step is 0.1 sec.
+    lim : array or list [min, max]. Default is [-7, -7].
+        The corrs view lims.
+    smooth : boolean True or False
+        Smooth the results or not.
+    figsize : array or list, [size_X, size_Y]
+        The size of the figure.
+        If figsize=None, the size of the figure will be ajusted automatically.
+    cmap : matplotlib colormap or None. Default is None.
+        The colormap for the figure.
+        If cmap=None, the ccolormap will be 'bwr'.
+    outline : bool True or False. Default is False.
+        Outline the significant areas or not.
+    """
+
+    # get the number of channels
+    nchls = stats.shape[0]
+
+    # get the number of time-points
+    ts = stats.shape[1]
+
+    # get the start time and the time step
+    start_t = time_unit[0]
+    tstep = time_unit[1]
+
+    # calculate the end time
+    end_t = start_t + ts * tstep
+
+    print(start_t, tstep, end_t)
+
+    # initialize the x
+    x = np.arange(start_t, end_t, tstep)
+
+    # set labels of the channels
+    if chllabels == None:
+
+        chllabels = []
+        for i in range(nchls):
+
+            if i % 10 == 0 and i != 10:
+                newlabel = str(i + 1) + "st"
+            elif i % 10 == 1 and i != 11:
+                newlabel = str(i + 1) + "nd"
+            elif i % 10 == 2 and i != 12:
+                newlabel = str(i + 1) + "rd"
+            else:
+                newlabel = str(i + 1) + "th"
+            chllabels.append(newlabel)
+
+    if smooth == True:
+
+        t = ts * 50
+
+        x_soft = np.linspace(x.min(), x.max(), t)
+        y_soft = np.zeros([nchls, t])
+
+        samplerate = int(1 / tstep) * 50
+        b, a = signal.butter(4, 2*30/samplerate, 'lowpass')
+
+        for i in range(nchls):
+            f = interp1d(x, stats[i, :, 0], kind='cubic')
+            y_soft[i] = f(x_soft)
+            y_soft[i] = signal.filtfilt(b, a, y_soft[i])
+
+        rlts = y_soft
+
+    if smooth == False:
+        rlts = stats[:, :, 0]
+
+    print(rlts.shape)
+
+    # get min of lims & max of lims
+    limmin = lim[0]
+    limmax = lim[1]
+
+    if cmap == None:
+        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls*0.16), clim=(limmin, limmax), origin='low')
+    else:
+        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls * 0.16), clim=(limmin, limmax), origin='low', cmap=cmap)
+
+    fig = plt.gcf()
+    size = fig.get_size_inches()
+
+    if figsize == None:
+        size_x = ts*tstep*(size[0]-2)+2
+        size_y = nchls*0.2*(size[1]-1.5)+1.5
+    else:
+        size_x = figsize[0]
+        size_y = figsize[1]
+
+    fig.set_size_inches(size_x, size_y)
+
+    cb = plt.colorbar()
+    cb.ax.tick_params(labelsize=16)
+    font = {'size': 18}
+    cb.set_label("Similarity", fontdict=font)
+
+    xi = []
+
+    for i in range(nchls):
+        xi.append(0.16*i + 0.08)
+
+    yi = chllabels
+
+    plt.tick_params(labelsize=18)
+    plt.yticks(xi, yi, fontsize=18)
+
+    if outline == True:
+        ps = stats[:, :, 1]
+
+        for i in range(nchls):
+            for j in range(ts):
+
+                if ps[i, j] < 0.05:
+                    ps[i, j] = 0
+                else:
+                    ps[i, j] = 1
+
+        x = np.linspace(start_t+0.5*tstep, end_t-0.5*tstep, ts)
+        y = np.linspace(0.08, 0.16*nchls-0.08, nchls)
+        X, Y = np.meshgrid(x, y)
+        plt.contour(X, Y, ps, [0, 1])
+
+    plt.ylabel("Channel", fontsize=20)
+    plt.xlabel("Time (s)", fontsize=20)
+
+    plt.show()
+
+
 ' a function for plotting the RSA-result regions by 3 cuts (frontal, axial & lateral) '
 
-def plot_brainrsa_regions(img, threshold=None, background=get_bg_ch2()):
+def plot_brainrsa_regions(img, threshold=None, background=get_bg_ch2(), type='r'):
 
     """
     Plot the RSA-result regions by 3 cuts (frontal, axial & lateral)
@@ -558,6 +704,8 @@ def plot_brainrsa_regions(img, threshold=None, background=get_bg_ch2()):
         None, the threshold-correction will not work.
     background : Niimg-like object or string. Default is stuff.get_bg_ch2()
         The background image that the RSA results will be plotted on top of.
+    type : string 'r' or 't'
+        The type of result (r-values or t-values).
     """
 
     imgarray = nib.load(img).get_data()
@@ -575,15 +723,19 @@ def plot_brainrsa_regions(img, threshold=None, background=get_bg_ch2()):
 
             img = nib.Nifti1Image(imgarray, affine)
 
-        plotting.plot_roi(roi_img=img, bg_img=background, threshold=0, vmin=0.1, vmax=1,
+        if type == 'r':
+            plotting.plot_roi(roi_img=img, bg_img=background, threshold=0, vmin=0.1, vmax=1,
                           title="Similarity", resampling_interpolation="continuous")
+        if type == 't':
+            plotting.plot_roi(roi_img=img, bg_img=background, threshold=0, vmin=-7, vmax=7,
+                              title="Similarity", resampling_interpolation="continuous")
 
         plt.show()
 
 
 ' a function for plotting the RSA-result by different cuts '
 
-def plot_brainrsa_montage(img, threshold=None, slice=[6, 6, 6], background=get_bg_ch2bet()):
+def plot_brainrsa_montage(img, threshold=None, slice=[6, 6, 6], background=get_bg_ch2bet(), type='r'):
 
     """
     Plot the RSA-result by different cuts
@@ -604,6 +756,8 @@ def plot_brainrsa_montage(img, threshold=None, slice=[6, 6, 6], background=get_b
         cut in the y direction, slice_z1 & slice_z2 represent the coordinates of each cut in the z direction.
     background : Niimg-like object or string. Default is stuff.get_bg_ch2bet()
         The background image that the RSA results will be plotted on top of.
+    type : string 'r' or 't'
+        The type of result (r-values or t-values).
     """
 
     imgarray = nib.load(img).get_data()
@@ -624,24 +778,29 @@ def plot_brainrsa_montage(img, threshold=None, slice=[6, 6, 6], background=get_b
         slice_y = slice[1]
         slice_z = slice[2]
 
+        if type == 'r':
+            vmax = 1
+        if type == 't':
+            vmax = 7
+
         if slice_x != 0:
             plotting.plot_stat_map(stat_map_img=img, bg_img=background, display_mode='x', cut_coords=slice_x,
-                                title="Similarity -sagittal", draw_cross=True, vmax=1)
+                                title="Similarity -sagittal", draw_cross=True, vmax=vmax)
 
         if slice_y != 0:
             plotting.plot_stat_map(stat_map_img=img, bg_img=background, display_mode='y', cut_coords=slice_y,
-                                title="Similarity -coronal", draw_cross=True, vmax=1)
+                                title="Similarity -coronal", draw_cross=True, vmax=vmax)
 
         if slice_z != 0:
             plotting.plot_stat_map(stat_map_img=img, bg_img=background, display_mode='z', cut_coords=slice_z,
-                                title="Similarity -axial", draw_cross=True, vmax=1)
+                                title="Similarity -axial", draw_cross=True, vmax=vmax)
 
         plt.show()
 
 
 ' a function for plotting the 2-D projection of the RSA-result '
 
-def plot_brainrsa_glass(img, threshold=None):
+def plot_brainrsa_glass(img, threshold=None, type='r'):
 
     """
     Plot the 2-D projection of the RSA-result
@@ -654,6 +813,8 @@ def plot_brainrsa_glass(img, threshold=None):
         The threshold of the number of voxels used in correction.
         If threshold=n, only the similarity clusters consisting more than threshold voxels will be visible. If it is
         None, the threshold-correction will not work.
+    type : string 'r' or 't'
+        The type of result (r-values or t-values).
     """
 
     imgarray = nib.load(img).get_data()
@@ -670,14 +831,17 @@ def plot_brainrsa_glass(img, threshold=None):
             imgarray = correct_by_threshold(imgarray, threshold)
             img = nib.Nifti1Image(imgarray, affine)
 
-        plotting.plot_glass_brain(img, colorbar=True, title="Similarity", black_bg=True, draw_cross=True, vmax=1)
+        if type == 'r':
+            plotting.plot_glass_brain(img, colorbar=True, title="Similarity", black_bg=True, draw_cross=True, vmax=1)
+        if type == 't':
+            plotting.plot_glass_brain(img, colorbar=True, title="Similarity", black_bg=True, draw_cross=True, vmax=7)
 
         plt.show()
 
 
 ' a function for plotting the RSA-result into a brain surface '
 
-def plot_brainrsa_surface(img, threshold=None):
+def plot_brainrsa_surface(img, threshold=None, type='r'):
 
     """
     Plot the RSA-result into a brain surface
@@ -690,6 +854,8 @@ def plot_brainrsa_surface(img, threshold=None):
         The threshold of the number of voxels used in correction.
         If threshold=n, only the similarity clusters consisting more than threshold voxels will be visible. If it is
         None, the threshold-correction will not work.
+    type : string 'r' or 't'
+        The type of result (r-values or t-values).
     """
 
     imgarray = nib.load(img).get_data()
@@ -711,24 +877,43 @@ def plot_brainrsa_surface(img, threshold=None):
         texture_left = surface.vol_to_surf(img, fsaverage.pial_left)
         texture_right = surface.vol_to_surf(img, fsaverage.pial_right)
 
-        plotting.plot_surf_stat_map(fsaverage.pial_left, texture_left, hemi='left', threshold=0.1,
-                                    bg_map=fsaverage.sulc_right, colorbar=False, vmax=0.8, darkness=0.7)
+        # type='r'
+        if type == 'r':
+            plotting.plot_surf_stat_map(fsaverage.pial_left, texture_left, hemi='left', threshold=0.1,
+                                        bg_map=fsaverage.sulc_right, colorbar=False, vmax=0.8, darkness=0.7)
 
-        plotting.plot_surf_stat_map(fsaverage.pial_right, texture_right, hemi='right', threshold=0.1,
-                                    bg_map=fsaverage.sulc_right, colorbar=True, vmax=0.8, darkness=0.7)
+            plotting.plot_surf_stat_map(fsaverage.pial_right, texture_right, hemi='right', threshold=0.1,
+                                        bg_map=fsaverage.sulc_right, colorbar=True, vmax=0.8, darkness=0.7)
 
-        plotting.plot_surf_stat_map(fsaverage.pial_right, texture_left, hemi='left', threshold=0.1,
-                                    bg_map=fsaverage.sulc_right, colorbar=False, vmax=0.8, darkness=0.7)
+            plotting.plot_surf_stat_map(fsaverage.pial_right, texture_left, hemi='left', threshold=0.1,
+                                        bg_map=fsaverage.sulc_right, colorbar=False, vmax=0.8, darkness=0.7)
 
-        plotting.plot_surf_stat_map(fsaverage.pial_left, texture_right, hemi='right', threshold=0.1,
-                                    bg_map=fsaverage.sulc_right, colorbar=True, vmax=0.8, darkness=0.7)
+            plotting.plot_surf_stat_map(fsaverage.pial_left, texture_right, hemi='right', threshold=0.1,
+                                        bg_map=fsaverage.sulc_right, colorbar=True, vmax=0.8, darkness=0.7)
+
+            plt.show()
+
+        # type='t'
+        if type == 't':
+            plotting.plot_surf_stat_map(fsaverage.pial_left, texture_left, hemi='left', threshold=0.8,
+                                        bg_map=fsaverage.sulc_right, colorbar=False, darkness=0.7)
+
+            plotting.plot_surf_stat_map(fsaverage.pial_right, texture_right, hemi='right', threshold=0.8,
+                                        bg_map=fsaverage.sulc_right, colorbar=True, darkness=0.7)
+
+            plotting.plot_surf_stat_map(fsaverage.pial_right, texture_left, hemi='left', threshold=0.8,
+                                        bg_map=fsaverage.sulc_right, colorbar=False, darkness=0.7)
+
+            plotting.plot_surf_stat_map(fsaverage.pial_left, texture_right, hemi='right', threshold=0.8,
+                                        bg_map=fsaverage.sulc_right, colorbar=True, darkness=0.7)
+
+            plt.show()
 
-        plt.show()
 
 
 ' a function for plotting the RSA-result by a set of images '
 
-def plot_brainrsa_rlts(img, threshold=None, slice=[6, 6, 6], background=None):
+def plot_brainrsa_rlts(img, threshold=None, slice=[6, 6, 6], background=None, type='r'):
 
     """
     Plot the RSA-result by a set of images
@@ -743,6 +928,8 @@ def plot_brainrsa_rlts(img, threshold=None, slice=[6, 6, 6], background=None):
         None, the threshold-correction will not work.
     background : Niimg-like object or string. Default is None.
         The background image that the RSA results will be plotted on top of.
+    type : string 'r' or 't'
+        The type of result (r-values or t-values).
     """
 
     imgarray = nib.load(img).get_data()
@@ -760,19 +947,18 @@ def plot_brainrsa_rlts(img, threshold=None, slice=[6, 6, 6], background=None):
 
         if background == None:
 
-            plot_brainrsa_regions(img, threshold=threshold)
+            plot_brainrsa_regions(img, threshold=threshold, type=type)
 
-            plot_brainrsa_montage(img, threshold=threshold, slice=slice)
+            plot_brainrsa_montage(img, threshold=threshold, slice=slice, type=type)
 
-            plot_brainrsa_glass(img, threshold=threshold)
+            plot_brainrsa_glass(img, threshold=threshold, type=type)
 
-            plot_brainrsa_surface(img, threshold=threshold)
+            plot_brainrsa_surface(img, threshold=threshold, type=type)
 
         else:
 
-            plot_brainrsa_regions(img, threshold=threshold, background=background)
+            plot_brainrsa_regions(img, threshold=threshold, background=background, type=type)
 
-            plot_brainrsa_montage(img, threshold=threshold, slice=slice, background=background)
-
-            plot_brainrsa_surface(img, threshold=threshold)
+            plot_brainrsa_montage(img, threshold=threshold, slice=slice, background=background, type=type)
 
+            plot_brainrsa_surface(img, threshold=threshold, type=type)
\ No newline at end of file
